/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.labelprovider;

import org.fortiss.tooling.base.annotation.AnnotationEntry;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.base.ui.annotation.view.IAnnotationViewPart;

/**
 * Base class for label providers that access attributes of {@link IModelElement}s (instead of
 * referring to {@link IAnnotatedSpecification}s).
 * 
 * @author Simon
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: B536A7A0CD44894367944450DE0C29C4
 */
public abstract class ElementLabelProviderBase extends LabelProviderBase {

	/** Creates a new {@link ElementLabelProviderBase}. */
	public ElementLabelProviderBase(IAnnotationViewPart viewPart) {
		super(viewPart);
	}

	/** {@inheritDoc} */
	@Override
	public String getText(Object element) {
		if(!(element instanceof AnnotationEntry)) {
			return "";
		}

		String text = getText(((AnnotationEntry)element).getModelElement());

		return (text != null) ? text : "";
	}

	/** Returns the text for the label for the given {@link IModelElement}. */
	protected abstract String getText(IModelElement modelElement);
}
