/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2013 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dialog;

import java.util.ArrayList;
import java.util.List;

import org.conqat.ide.commons.ui.jface.TreeContentProviderBase;
import org.eclipse.jface.dialogs.TitleAreaDialog;
import org.eclipse.jface.viewers.CheckStateChangedEvent;
import org.eclipse.jface.viewers.CheckboxTreeViewer;
import org.eclipse.jface.viewers.ICheckStateListener;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;

/**
 * A {@link TitleAreaDialog} that hosts a {@link CheckboxTreeViewer}.
 * 
 * @author czhang
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating GREEN Hash: 12D549CCF3FE22DF4C1CBA14E17B1AF0
 */
public class CheckBoxTreeDialog extends TitleAreaDialog {

	/** The {@link CheckboxTreeViewer}. */
	private CheckboxTreeViewer checkboxTreeViewer;

	/** Root elements used to define the contents of the {@link CheckboxTreeViewer}. */
	private ArrayList<Object> rootElements;

	/** Selected objects. */
	private Object[] selectedObjects;

	/**
	 * TitleAreaDialog title. Passed to {@link #setTitle(String)} in
	 * {@link #createDialogArea(Composite)}.
	 */
	private String title;

	/**
	 * Dialog message. Passed to {@link #setMessage(String)} in {@link #createDialogArea(Composite)}
	 * .
	 */
	private String message;

	/** Constructor. */
	public CheckBoxTreeDialog(Shell parentShell, List<?> roots, String title, String message) {
		super(parentShell);
		if(roots == null) {
			rootElements = new ArrayList<Object>();
		} else {
			rootElements = new ArrayList<Object>(roots);
		}
		this.title = title;
		this.message = message;
		setBlockOnOpen(true);
	}

	/** {@inheritDoc} */
	@Override
	protected Control createDialogArea(Composite parent) {
		Composite container = (Composite)super.createDialogArea(parent);
		super.setTitle(title);
		super.setMessage(message);

		checkboxTreeViewer = new CheckboxTreeViewer(container, SWT.NONE);
		checkboxTreeViewer.getControl().setLayoutData(new GridData(GridData.FILL_BOTH));
		checkboxTreeViewer.setContentProvider(new TreeContentProviderBase() {

			@Override
			public Object[] getChildren(Object parentElement) {
				return parentElement == rootElements ? rootElements.toArray() : null;
			}
		});
		checkboxTreeViewer.setInput(rootElements);
		checkboxTreeViewer.addCheckStateListener(new ICheckStateListener() {

			@Override
			public void checkStateChanged(CheckStateChangedEvent event) {
				setSelectedObjects();
			}
		});
		return container;
	}

	/** Gets selectedObjects. */
	public Object[] getSelectedObjects() {
		return selectedObjects;
	}

	/** Sets selectedObjects. */
	private void setSelectedObjects() {
		selectedObjects = checkboxTreeViewer.getCheckedElements();
	}
}
