/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dialog;

import static org.fortiss.tooling.base.ui.dialog.MessageUtilsExtended.showWarningInUIThread;

import org.fortiss.tooling.base.compose.ModelElementWithRefCopyMessage;
import org.fortiss.tooling.base.model.element.IModelElementSpecification;
import org.fortiss.tooling.kernel.extension.LogMessageHandler;
import org.fortiss.tooling.kernel.extension.data.ILogMessageContext;
import org.fortiss.tooling.kernel.extension.data.LogMessage;

/**
 * {@link LogMessageHandler} that displays warning dialogs of {@link ModelElementWithRefCopyMessage}
 * s which are emitted when a user copies elements that referencing
 * {@link IModelElementSpecification}s.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 569C07E297B68D0F11D18A7AFC5306DA
 */
public class ModelElementWithRefCopyMessageHandler implements LogMessageHandler {

	/** Title of the dialog. */
	private static final String TITLE = "References to external model elements.";

	/** {@inheritDoc} */
	@Override
	public boolean acceptMessage(LogMessage message, ILogMessageContext context) {
		return (message instanceof ModelElementWithRefCopyMessage) ? true : false;
	}

	/** {@inheritDoc} */
	@Override
	public void showMessage(LogMessage message) {
		showWarningInUIThread(TITLE, message.getMessage());
	}
}
