/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editor;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.impl.AdapterImpl;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.gef.DefaultEditDomain;
import org.eclipse.gef.EditDomain;
import org.eclipse.gef.commands.CommandStack;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.PartInitException;
import org.fortiss.tooling.base.ui.internal.command.GEF2ToolingKernelCommandStack;
import org.fortiss.tooling.kernel.service.IPersistencyService;

/**
 * GEF editor base implementation.
 * 
 * It provides {@link EditDomain} and thus a {@link CommandStack}.
 * 
 * @author hummel
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: DC9C2F53C31BA1266F540BA4615E67F1
 */
public abstract class GEFEditorBase<T extends EObject> extends
		org.fortiss.tooling.kernel.ui.extension.base.EditorBase<T> {

	/** The edit domain (used e.g. for managing the command stack). */
	private final EditDomain editDomain = new DefaultEditDomain(this);

	/** The adapter used to find out when the edited object is removed. */
	private final Adapter removeAdapter = new AdapterImpl() {
		@Override
		public void notifyChanged(Notification notification) {
			// object is deleted if it does not have a parent and is not a
			// top-level element
			if(getEditedObject().eContainer() == null &&
					IPersistencyService.getInstance().getTopLevelElementFor(getEditedObject()) != null) {
				getSite().getPage().closeEditor(GEFEditorBase.this, false);
			}
		}
	};

	/** {@inheritDoc} */
	@Override
	public void init(IEditorSite site, IEditorInput input) throws PartInitException {
		super.init(site, input);

		// install another command stack
		editDomain.setCommandStack(new GEF2ToolingKernelCommandStack(getEditedObject()));

		getEditedObject().eAdapters().add(removeAdapter);
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		if(getEditedObject() != null) {
			getEditedObject().eAdapters().remove(removeAdapter);
		}
		super.dispose();
	}

	/** {@inheritDoc} */
	@SuppressWarnings("rawtypes")
	@Override
	public Object getAdapter(Class adapter) {
		// The command stack adaption is required for some of the GEF actions
		if(adapter == CommandStack.class) {
			return getCommandStack();
		}

		return super.getAdapter(adapter);
	}

	/** Returns the command stack. */
	protected final CommandStack getCommandStack() {
		return editDomain.getCommandStack();
	}

	/** Return the edit domain */
	protected final EditDomain getEditDomain() {
		return editDomain;
	}
}
