/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.properties.view;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.fortiss.tooling.base.model.element.IModelElementSpecification;
import org.fortiss.tooling.kernel.ui.extension.base.PropertySectionBase;

/**
 * Base class for adding copy-and-paste functionality to property sections.
 * 
 * @author ratiu
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating GREEN Hash: 6428F3826328029F86C7993F10E23746
 */
public abstract class PropertySectionWithCopyPasteBase<T extends IModelElementSpecification>
		extends PropertySectionBase {

	/** Widget for clip board copy. */
	protected Button clipboardCopy;

	/** Widget for clip board paste. */
	protected Button clipboardPaste;

	/** The current edited specification. */
	protected T specification;

	/** Copy-paste composite. */
	protected void createCopyPasteComposite() {
		final Composite copyPasteComposite = getWidgetFactory().createComposite(composite);
		copyPasteComposite.setLayout(new FillLayout(SWT.HORIZONTAL));
		clipboardCopy = getWidgetFactory().createButton(copyPasteComposite, "copy", SWT.PUSH);
		clipboardCopy.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				setClipboardSpec(specification);
				clipboardPaste.setEnabled(false);
			}
		});
		clipboardPaste = getWidgetFactory().createButton(copyPasteComposite, "paste", SWT.PUSH);
		clipboardPaste.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				if(getClipboardSpec() != null && getClipboardSpec() != specification) {
					doPerformCopy();
					setClipboardSpec(null);
					clipboardPaste.setEnabled(false);
				}
			}
		});
		clipboardPaste.setEnabled(false);
		createFormEntry(copyPasteComposite, "Clipboard");
	}

	/** Performs the copy. */
	protected abstract void doPerformCopy();

	/** Sets the specification to be saved in the clipboard. */
	protected abstract void setClipboardSpec(T currentSpec);

	/** Returns the current specification from the clipboard. */
	protected abstract T getClipboardSpec();
}
