/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import org.fortiss.tooling.base.model.layout.Dimension;
import org.fortiss.tooling.base.model.layout.Point;

/**
 * Utility code to support zooming.
 * 
 * @author hummel
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 354CBE4BDFBB621FEA02D3F396A9ED55
 */
public class ZoomUtils {

	/**
	 * Converts a point expressed in screen coordinates, into a point in internal coordinates,
	 * taking the zoom into account.
	 */
	public static Point screenToInternalPoint(Point pos, double zoom) {
		return pos.scale(1 / zoom);
	}

	/**
	 * Converts a point expressed in internal coordinates, into a point in screen coordinates,
	 * taking the zoom into account.
	 */
	public static Point internalToScreenPoint(Point pos, double zoom) {
		return pos.scale(zoom);
	}

	/**
	 * Converts a point expressed in screen coordinates, into a point in internal coordinates,
	 * taking the zoom into account.
	 */
	public static Dimension screenToInternalDimension(Dimension dim, double zoom) {
		return dim.scale(1 / zoom);
	}

	/**
	 * Converts a point expressed in internal coordinates, into a point in screen coordinates,
	 * taking the zoom into account.
	 */
	public static Dimension internalToScreenDimension(Dimension dim, double zoom) {
		return dim.scale(zoom);
	}
}
