/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui;

import static java.lang.System.mapLibraryName;
import static org.eclipse.core.runtime.FileLocator.toFileURL;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 2CE0B866470A215C83C58AEA7E35B6B9
 */
public class ToolingGraphicsGLUIActivator extends AbstractUIPlugin {

	/** The plug-in ID. */
	public static final String PLUGIN_ID = ToolingGraphicsGLUIActivator.class.getPackage()
			.getName(); //$NON-NLS-1$

	/** The shared instance. */
	private static ToolingGraphicsGLUIActivator plugin;

	/** {@inheritDoc} */
	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
		System.out.println(PLUGIN_ID + " activated.");

		System.out.println("Preloading native LWJGL libraries.");

		boolean is64bit;
		if(System.getProperty("os.name").contains("Windows")) {
			is64bit = (System.getenv("ProgramFiles(x86)") != null);
		} else {
			is64bit = (System.getProperty("os.arch").indexOf("64") != -1);
		}

		// preload JEMALLOC
		String jemallocLibPath = loadPluginLocalLibrary(getBundle(), "jemalloc", is64bit);
		System.out.println("LWJGL jemalloc library path = " + jemallocLibPath);
		// LWJGL has its own System.load() call when this property is provided
		System.setProperty("org.lwjgl.system.jemalloc.libname", jemallocLibPath);

		// preload LWJGL
		String lwjglLibPath = loadPluginLocalLibrary(getBundle(), "lwjgl", is64bit);
		System.out.println("LWJGL lwjgl library path = " + lwjglLibPath);
		System.out.println("Done preloading native LWJGL libraries.");
	}

	/** Load the given local library using {@link System#load(String)}. */
	private String loadPluginLocalLibrary(Bundle bundle, String libraryName, boolean is64bit)
			throws Exception {
		String osLibName = mapLibraryName(libraryName);
		String bundleLocalLibraryFolder;
		if(!is64bit) {
			String[] parts = osLibName.split(".");
			osLibName = parts[0] + "32." + parts[1];
			bundleLocalLibraryFolder = "/lib/x32";
		} else {
			bundleLocalLibraryFolder = "/lib/x64";
		}
		String fullPath =
				toFileURL(bundle.getEntry(bundleLocalLibraryFolder)).getPath() + osLibName;
		System.load(fullPath);
		return fullPath;
	}

	/** {@inheritDoc} */
	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/** Returns the shared instance. */
	public static ToolingGraphicsGLUIActivator getDefault() {
		return plugin;
	}

	/** Returns the image descriptor for the given icon file. */
	public static ImageDescriptor getImageDescriptor(String path) {
		return imageDescriptorFromPlugin(PLUGIN_ID, path);
	}
}
