/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal;

import static org.fortiss.tooling.kernel.utils.LoggingUtils.error;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.fortiss.tooling.kernel.extension.ITutorialProvider;
import org.fortiss.tooling.kernel.extension.data.TutorialStepBase;
import org.fortiss.tooling.kernel.service.ITutorialService;
import org.fortiss.tooling.kernel.ui.ToolingKernelUIActivator;
import org.fortiss.tooling.kernel.ui.extension.ITutorialStepUI;
import org.fortiss.tooling.kernel.ui.extension.ITutorialUIProvider;
import org.fortiss.tooling.kernel.ui.extension.ITutorialUIWhitelistProvider;
import org.fortiss.tooling.kernel.ui.internal.editor.TutorialStepUIEditor;
import org.fortiss.tooling.kernel.ui.internal.editor.TutorialStepUIEditorInput;
import org.fortiss.tooling.kernel.ui.service.ITutorialUIService;

/**
 * Implementation of {@link ITutorialUIService}.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public final class TutorialUIService implements ITutorialUIService, ITutorialUIWhitelistProvider {

	/** The map from tutorial providers to their UI counter-part. */
	private final Map<Class<? extends ITutorialProvider>, Class<? extends ITutorialUIProvider>> providerMap =
			new HashMap<Class<? extends ITutorialProvider>, Class<? extends ITutorialUIProvider>>();
	/** The map of tutorial UI provider instances. */
	private final Map<Class<? extends ITutorialUIProvider>, ITutorialUIProvider> instanceMap =
			new HashMap<Class<? extends ITutorialUIProvider>, ITutorialUIProvider>();

	/** Initializes the service. */
	public void initializeService() {
		// nothing to do here
	}

	/** Starts the service. */
	public void startService() {
		// nothing to do here
	}

	/** {@inheritDoc} */
	@Override
	public void registerTutorialUIProvider(Class<? extends ITutorialProvider> nonUIprovider,
			Class<? extends ITutorialUIProvider> uiProvider) {
		if(!providerMap.containsKey(nonUIprovider)) {
			try {
				providerMap.put(nonUIprovider, uiProvider);
				instanceMap.put(uiProvider, uiProvider.newInstance());
			} catch(Exception e) {
				error(ToolingKernelUIActivator.getDefault(),
						"Failed to instantiate tutorial UI provider " + uiProvider.getName() + "!",
						e);
			}
		} else {
			StringBuilder sb = new StringBuilder();
			sb.append("TutorialProvider ").append(nonUIprovider.getName());
			sb.append(" already mapped to ").append(uiProvider.getName());
			sb.append("!");
			error(ToolingKernelUIActivator.getDefault(), sb.toString());
		}
	}

	/** {@inheritDoc} */
	@Override
	public boolean elementVisibleInNavigator(EObject element) {
		TutorialStepBase step = ITutorialService.getInstance().getActiveTutorialStep();
		while(step != null) {
			if(step instanceof ITutorialUIWhitelistProvider) {
				ITutorialUIWhitelistProvider p = (ITutorialUIWhitelistProvider)step;
				if(p.elementVisibleInNavigator(element)) {
					return true;
				}
			}
			step = step.getParent();
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean globalDefaultActionsVisible() {
		TutorialStepBase step = ITutorialService.getInstance().getActiveTutorialStep();
		while(step != null) {
			if(step instanceof ITutorialUIWhitelistProvider) {
				ITutorialUIWhitelistProvider p = (ITutorialUIWhitelistProvider)step;
				if(p.globalDefaultActionsVisible()) {
					return true;
				}
			}
			step = step.getParent();
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean contextMenuContributionVisible(EObject element, IContributionItem contribution) {
		TutorialStepBase step = ITutorialService.getInstance().getActiveTutorialStep();
		while(step != null) {
			if(step instanceof ITutorialUIWhitelistProvider) {
				ITutorialUIWhitelistProvider p = (ITutorialUIWhitelistProvider)step;
				if(p.contextMenuContributionVisible(element, contribution)) {
					return true;
				}
			}
			step = step.getParent();
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public void openInEditor(ITutorialStepUI selected) {
		try {
			IEditorInput input = new TutorialStepUIEditorInput(selected);
			PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage()
					.openEditor(input, TutorialStepUIEditor.class.getName(), true);
		} catch(PartInitException pex) {
			error(ToolingKernelUIActivator.getDefault(), pex.getMessage(), pex);
		}
	}
}
