/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.base;

import org.fortiss.tooling.kernel.extension.data.ITransformationContext;

/**
 * Base implementation of {@link ITransformationContext}, which stores a
 * reference to another context.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: F98256FB0E0A681F13136FC0C2348369
 */
public abstract class TransformationContextChainBase implements ITransformationContext {

	/** Stores the chained context. */
	protected final ITransformationContext chainedContext;

	/** Constructor. */
	public TransformationContextChainBase(ITransformationContext chainedContext) {
		this.chainedContext = chainedContext;
	}

	/** Constructor. */
	public TransformationContextChainBase() {
		this(null);
	}

	/** Returns the next {@link ITransformationContext} in the chain. */
	public ITransformationContext getNextContext() {
		return chainedContext;
	}

	/** Finds an ITransform of the given class in the chain. */
	@SuppressWarnings("unchecked")
	public <T extends ITransformationContext> T findContextInChain(Class<T> clazz) {
		if(clazz.isAssignableFrom(this.getClass())) {
			return (T)this;
		}
		if(chainedContext instanceof TransformationContextChainBase) {
			return ((TransformationContextChainBase)chainedContext).findContextInChain(clazz);
		}
		return null;
	}
}
