/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.internal;

import static org.fortiss.tooling.kernel.utils.LoggingUtils.error;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.common.command.CommandStackListener;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.ToolingKernelActivator;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.service.ICommandStackService;
import org.fortiss.tooling.kernel.service.IPersistencyService;

/**
 * This class implements the {@link ICommandStackService} interface. This class
 * mainly delegates its calls to the {@link IPersistencyService}.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 82CCE7AD2F21B0F48DBC904FF10F1C60
 */
public class CommandStackService implements ICommandStackService {

	/** {@inheritDoc} */
	@Override
	public void addCommandStackListener(ITopLevelElement target, CommandStackListener listener) {
		if(target != null) {
			target.addCommandStackListener(listener);
		}
	}

	/** {@inheritDoc} */
	@Override
	public void removeCommandStackListener(ITopLevelElement target, CommandStackListener listener) {
		if(target != null) {
			target.removeCommandStackListener(listener);
		} else {
			for(ITopLevelElement top : IPersistencyService.getInstance().getTopLevelElements()) {
				top.removeCommandStackListener(listener);
			}
		}
	}

	/** {@inheritDoc} */
	@Override
	public void runAsCommand(EObject target, Runnable runner) {
		ITopLevelElement context = IPersistencyService.getInstance().getTopLevelElementFor(target);
		context.runAsCommand(runner);
	}

	/** {@inheritDoc} */
	@Override
	public boolean canUndo(EObject target) {
		ITopLevelElement context = IPersistencyService.getInstance().getTopLevelElementFor(target);
		return context != null && context.canUndo();
	}

	/** {@inheritDoc} */
	@Override
	public boolean canRedo(EObject target) {
		ITopLevelElement context = IPersistencyService.getInstance().getTopLevelElementFor(target);
		return context != null && context.canRedo();
	}

	/** {@inheritDoc} */
	@Override
	public void undo(EObject target) {
		IPersistencyService.getInstance().getTopLevelElementFor(target).undo();
	}

	/** {@inheritDoc} */
	@Override
	public void redo(EObject target) {
		IPersistencyService.getInstance().getTopLevelElementFor(target).redo();
	}

	/** {@inheritDoc} */
	@Override
	public boolean isDirty(EObject target) {
		ITopLevelElement context = IPersistencyService.getInstance().getTopLevelElementFor(target);
		return context != null && context.isDirty();
	}

	/** {@inheritDoc} */
	@Override
	public void doSave(EObject target, IProgressMonitor monitor) {
		ITopLevelElement context = IPersistencyService.getInstance().getTopLevelElementFor(target);
		if(context != null && context.isDirty()) {
			try {
				context.doSave(monitor);
			} catch(Exception e) {
				error(ToolingKernelActivator.getDefault(), "Error while saving.", e);
			}
		}
	}
}
