/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.example;

import static org.fortiss.tooling.spiderchart.style.FontStyle.BLACK_VERDANA_10PT;
import static org.fortiss.tooling.spiderchart.style.FontStyle.BLACK_VERDANA_12PT;
import static org.fortiss.tooling.spiderchart.style.FontStyle.BLACK_VERDANA_14PT;
import static org.fortiss.tooling.spiderchart.style.FontStyle.BLACK_VERDANA_8PT;
import static org.fortiss.tooling.spiderchart.style.LineStyle.SOLID_BLACK_1PT;
import static org.fortiss.tooling.spiderchart.util.FontUtils.VERDANA_14PT;
import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.BLUE;
import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.DARK_GRAY;
import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.LIGHT_GRAY;
import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.NAVY;
import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.OLIVE;
import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.getDarkerColor;

import java.text.DecimalFormat;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.fortiss.tooling.spiderchart.model.Axis;
import org.fortiss.tooling.spiderchart.model.DataSeries;
import org.fortiss.tooling.spiderchart.model.SpiderChart;
import org.fortiss.tooling.spiderchart.style.AxisStyle;
import org.fortiss.tooling.spiderchart.style.ChartStyle;
import org.fortiss.tooling.spiderchart.style.DataSeriesStyle;
import org.fortiss.tooling.spiderchart.style.FillStyle;
import org.fortiss.tooling.spiderchart.style.FontStyle;
import org.fortiss.tooling.spiderchart.style.LegendStyle;
import org.fortiss.tooling.spiderchart.style.LineStyle;
import org.fortiss.tooling.spiderchart.widget.SpiderChartViewer;

/**
 * Example application for the spider chart widget.
 *
 * @author mondal
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: FA525F8C119797775BFAB25AC6DE8A3F
 */
@SuppressWarnings("javadoc")
public final class Sample {

	private static SpiderChartViewer viewer;

	private static void buildSpiderChart(final Shell shell) {
		SpiderChart spiderChart = new SpiderChart();
		spiderChart.setTitle("Smartphone Comparison Scale");
		spiderChart.setLegendLabel("Legend");

		Axis battery = new Axis("Battery", 0.0, 4.0);
		Axis camera = new Axis("Camera", 0.0, 7.0);
		Axis display = new Axis("Display", 0.0, 5.0);
		Axis memory = new Axis("Memory", 0.0, 5.0);
		Axis brand = new Axis("Brand", 0.0, 5.0);
		Axis screen = new Axis("Screen", 0.0, 5.0);
		spiderChart.addAxis(battery);
		spiderChart.addAxis(camera);
		spiderChart.addAxis(display);
		spiderChart.addAxis(memory);
		spiderChart.addAxis(brand);
		spiderChart.addAxis(screen);

		DataSeries iPhoneData = new DataSeries("iPhone 6");
		iPhoneData.setPoint(battery, 4.0);
		iPhoneData.setPoint(camera, 3.5);
		iPhoneData.setPoint(display, 4.0);
		iPhoneData.setPoint(memory, 4.6);
		iPhoneData.setPoint(brand, 5.0);
		iPhoneData.setPoint(screen, 3.8);
		spiderChart.addData(iPhoneData);

		DataSeries nexusData = new DataSeries("Nexus 6");
		nexusData.setPoint(battery, 3.0);
		nexusData.setPoint(camera, 4.5);
		nexusData.setPoint(display, 3.0);
		nexusData.setPoint(memory, 3.6);
		nexusData.setPoint(brand, 4.0);
		nexusData.setPoint(screen, 2.8);
		spiderChart.addData(nexusData);

		ChartStyle chartStyle = new ChartStyle(true, true, false);
		chartStyle.setTitleStyle(new FontStyle(VERDANA_14PT, getDarkerColor(BLUE)));
		LegendStyle legendStyle = new LegendStyle(BLUE, false, 5, BLACK_VERDANA_12PT);
		chartStyle.setLegendStyle(legendStyle);

		AxisStyle aStyle3Segs =
				new AxisStyle(SOLID_BLACK_1PT, BLACK_VERDANA_14PT, 3, BLACK_VERDANA_8PT,
						new DecimalFormat("#.##"));
		chartStyle.setAxisStyle(battery, aStyle3Segs);
		AxisStyle aStyle6Segs =
				new AxisStyle(SOLID_BLACK_1PT, BLACK_VERDANA_14PT, 6, BLACK_VERDANA_8PT,
						new DecimalFormat("#.##"));
		chartStyle.setAxisStyle(camera, aStyle6Segs);
		AxisStyle aStyle4Segs =
				new AxisStyle(SOLID_BLACK_1PT, BLACK_VERDANA_14PT, 4, BLACK_VERDANA_8PT,
						new DecimalFormat("#.##"));
		chartStyle.setAxisStyle(display, aStyle4Segs);
		chartStyle.setAxisStyle(memory, aStyle4Segs);
		chartStyle.setAxisStyle(brand, aStyle4Segs);
		chartStyle.setAxisStyle(screen, aStyle4Segs);
		chartStyle.setUseIndividualAxisSegments(false);
		chartStyle.setAxisSegments(4);
		chartStyle.setBackgroundFillStyle(new FillStyle(LIGHT_GRAY));
		chartStyle.setBackgroundLineStyle(new LineStyle(DARK_GRAY));

		LineStyle olive1pt = new LineStyle(OLIVE);
		FillStyle oliveFill = new FillStyle(OLIVE, 128);
		DataSeriesStyle iphoneStyle =
				new DataSeriesStyle(olive1pt, oliveFill, true, true, BLACK_VERDANA_10PT, 7,
						new DecimalFormat("#.#"));
		chartStyle.setDataSeriesStyle(iPhoneData, iphoneStyle);

		LineStyle navy1pt = new LineStyle(NAVY);
		FillStyle navyFill = new FillStyle(NAVY, 128);
		DataSeriesStyle nexusStyle =
				new DataSeriesStyle(navy1pt, navyFill, true, true, BLACK_VERDANA_10PT, 7,
						new DecimalFormat("#.#"));
		chartStyle.setDataSeriesStyle(nexusData, nexusStyle);

		viewer = new SpiderChartViewer(shell, spiderChart, chartStyle);
		viewer.setLayoutData(new GridData(GridData.FILL, GridData.FILL, true, true));
		Rectangle clientArea = shell.getClientArea();
		viewer.setBounds(clientArea.x, clientArea.y, clientArea.width, clientArea.height);
	}

	public static void main(final String[] args) {
		final Display display = new Display();
		final Shell shell = new Shell(display, SWT.DIALOG_TRIM);
		shell.setSize(800, 750);

		buildSpiderChart(shell);
		shell.open();

		while(!shell.isDisposed()) {
			if(!display.readAndDispatch()) {
				display.sleep();
			}
		}
		viewer.dispose();
		display.dispose();
	}
}
