/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.model;

import static java.util.Objects.requireNonNull;

/**
 * Class representing an axis of the spider chart.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating YELLOW Hash: 6C5390A8B21E0877312C9EB36F009A6B
 */
public final class Axis {
	/** The name of the axis. */
	private String name;
	/** The minimum value of the axis (at the center of the spider chart). */
	private Double minimumValue = 0.0;
	/** The maximum value of this axis. */
	private Double maximumValue = 1.0;

	/** Constructor. */
	public Axis(Double min, Double max) {
		this("", min, max);
	}

	/** Constructor. */
	public Axis(String name, Double min, Double max) {
		this.name = requireNonNull(name);
		this.minimumValue = requireNonNull(min);
		this.maximumValue = requireNonNull(max);
	}

	/** Returns maximum value. */
	public Double getMaximumValue() {
		return maximumValue;
	}

	/** Returns minimum value. */
	public Double getMinimumValue() {
		return minimumValue;
	}

	/** Returns name. */
	public String getName() {
		return name;
	}

	/** Returns the value for the given ratio of this axis. */
	public Double getAxisValue(Double ratio) {
		Double length = maximumValue - minimumValue;
		return minimumValue + ratio * length;
	}

	/** Returns the ratio for the given value. */
	public Double getAxisRatio(Double value) {
		return (value - minimumValue) / (maximumValue - minimumValue);
	}
}
