/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.model;

import static java.util.Objects.requireNonNull;

import java.util.HashMap;
import java.util.Map;

/**
 * Class representing series of data for each axis of a spider chart.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating YELLOW Hash: 7CFFF87C0D159572D525D01C01040F7E
 */
public final class DataSeries {
	/** The name of the data series. */
	private String name;
	/** The points for each axis. */
	private Map<Axis, Double> points = new HashMap<Axis, Double>();

	/** Constructor. */
	public DataSeries(String name) {
		setName(name);
	}

	/** Sets name. */
	public void setName(String name) {
		this.name = requireNonNull(name);
	}

	/** Returns name. */
	public String getName() {
		return name;
	}

	/** Sets the point for the given axis. */
	public void setPoint(Axis axis, Double value) {
		points.put(requireNonNull(axis), requireNonNull(value));
	}

	/** Returns the point for the given axis. */
	public Double getAxisValue(Axis a) {
		return points.get(a);
	}
}
