/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.style;

import static org.fortiss.tooling.spiderchart.style.FontStyle.BLACK_VERDANA_10PT;
import static org.fortiss.tooling.spiderchart.style.LineStyle.SOLID_BLACK_1PT;
import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.LIGHT_GRAY;

import java.text.DecimalFormat;

import org.fortiss.tooling.spiderchart.model.DataSeries;

/**
 * Class for all style attributes of {@link DataSeries data series}.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating YELLOW Hash: 605C2C16FA2B5715C060458F6A9C976B
 */
public final class DataSeriesStyle {
	/** The line style of the data series. */
	private final LineStyle lineStyle;
	/** The fill style of the data series. */
	private final FillStyle fillStyle;
	/** The font style of the data series indicators. */
	private final FontStyle indicatorLabelStyle;
	/** The size of the indicator box. Default is 7. */
	private final int indicatorSize;
	/** The flag to show indicator boxes. */
	private final boolean showIndicators;
	/** The flag to show indicator labels. */
	private final boolean showIndicatorLabels;
	/** The decimal formatter of the segment labels of the axis. */
	private DecimalFormat decimalFormat;

	/** Constructor. */
	public DataSeriesStyle(LineStyle lineStyle, FillStyle fillStyle, boolean withIndicators,
			boolean withIndicatorLabels, FontStyle indicatorStyle, int indicatorSize,
			DecimalFormat decimalFormat) {
		this.lineStyle = lineStyle;
		this.fillStyle = fillStyle;
		this.showIndicators = withIndicators;
		this.showIndicatorLabels = withIndicatorLabels;
		this.indicatorLabelStyle = indicatorStyle;
		this.indicatorSize = indicatorSize;
		this.decimalFormat = decimalFormat;
	}

	/** Constructor. */
	public DataSeriesStyle() {
		this(SOLID_BLACK_1PT, new FillStyle(LIGHT_GRAY), true, true, BLACK_VERDANA_10PT, 7,
				new DecimalFormat("#.##"));
	}

	/** Returns line style. */
	public LineStyle getLineStyle() {
		return lineStyle;
	}

	/** Returns fill style. */
	public FillStyle getFillStyle() {
		return fillStyle;
	}

	/** Returns whether to show indicators. */
	public boolean isShowIndicators() {
		return showIndicators;
	}

	/** Returns whether to show indicator labels. */
	public boolean isShowIndicatorLabels() {
		return showIndicatorLabels;
	}

	/** Returns the indicator label style. */
	public FontStyle getIndicatorLabelStyle() {
		return indicatorLabelStyle;
	}

	/** Returns the size of the indicator box. */
	public int getIndicatorSize() {
		return indicatorSize;
	}

	/** Returns the decimal format. */
	public DecimalFormat getDecimalFormat() {
		return decimalFormat;
	}
}
