/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.widget;

import static org.fortiss.tooling.base.ui.utils.GCUtils.createGraphicsContextManager;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.events.ControlListener;
import org.eclipse.swt.events.PaintEvent;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.widgets.Canvas;
import org.eclipse.swt.widgets.Composite;
import org.fortiss.tooling.base.ui.utils.GCUtils;
import org.fortiss.tooling.spiderchart.model.SpiderChart;
import org.fortiss.tooling.spiderchart.style.ChartStyle;

/**
 * Represents a {@link Canvas} on which chart will be drawn.
 *
 * @author mondal
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 1CFC7CA547E4FAF1E0BE7748B10A11C4
 */
final class SpiderChartSWTCanvas extends Canvas {

	/** The chart style. */
	private final ChartStyle style;
	/** The chart widget. */
	private final SpiderChartWidget chartWidget;
	/** The title widget. */
	private final SpiderChartTitleWidget titleWidget;
	/** The legend widget. */
	private final SpiderChartLegendWidget legendWidget;

	/** Constructor */
	public SpiderChartSWTCanvas(Composite parent, SpiderChart chart, ChartStyle style) {
		super(parent, SWT.NONE);
		this.style = style;
		this.chartWidget = new SpiderChartWidget(chart, style);
		this.titleWidget = new SpiderChartTitleWidget(chart, style);
		this.legendWidget = new SpiderChartLegendWidget(chart, style);

		addPaintListener(e -> drawChart(e));

		addControlListener(new ControlListener() {
			@Override
			public void controlMoved(ControlEvent e) {
				// not used
			}

			@Override
			public void controlResized(ControlEvent e) {
				layoutChart();
			}
		});
	}

	/** Computes the bounding boxes of the chart components. */
	private void layoutChart() {
		double charMarginPercent = style.getRelativeMargin();
		Rectangle bounds = getBounds();
		int widthMargin = (int)(bounds.width * charMarginPercent);
		int heightMargin = (int)(bounds.height * charMarginPercent);

		int chartY = 0;
		int widthRemaining = bounds.width;
		int heightRemaining = bounds.height;

		if(style.isShowTitle()) {
			titleWidget.setBounds(0, 0, bounds.width - 1, heightMargin - 1);
			heightRemaining -= heightMargin;
			chartY = heightMargin;
		}
		if(style.isShowLegend()) {
			if(style.getLegendStyle().isVerticalLayout()) {
				legendWidget.setBounds(bounds.width - widthMargin, bounds.height - heightRemaining,
						widthMargin - 1, heightRemaining - 1);
				widthRemaining -= widthMargin;
			} else {
				legendWidget.setBounds(0, bounds.height - heightMargin, bounds.width - 1,
						heightMargin - 1);
				heightRemaining -= heightMargin;
			}
		}
		chartWidget.setBounds(0, chartY, widthRemaining, heightRemaining);
	}

	/** Draws the spider chart. */
	private void drawChart(PaintEvent e) {
		GCUtils.GCStateManager gcState = createGraphicsContextManager(e.gc);
		if(style.isShowTitle()) {
			titleWidget.draw(gcState);
		}
		chartWidget.draw(gcState);
		if(style.isShowLegend()) {
			legendWidget.draw(gcState);
		}
	}
}
