/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.widget;

import org.fortiss.tooling.spiderchart.model.SpiderChart;
import org.fortiss.tooling.spiderchart.style.ChartStyle;

/**
 * Base class for elements of the spider chart.
 *
 * @author mondal
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: C26D712A400E929262106865306F385E
 */
public abstract class SpiderChartWidgetBase {
	/** The spider chart this component belongs to. */
	protected final SpiderChart chart;
	/** The spider chart style information. */
	protected final ChartStyle style;
	/** The height of the component. */
	protected int height;
	/** The width of the component. */
	protected int width;
	/** The x location. */
	protected int x;
	/** The y location. */
	protected int y;

	/** Constructor. */
	public SpiderChartWidgetBase(SpiderChart chart, ChartStyle style) {
		this.chart = chart;
		this.style = style;
	}

	/** Sets the bounding rectangle area of this widget. */
	public void setBounds(int x, int y, int width, int height) {
		this.x = x;
		this.y = y;
		this.width = width;
		this.height = height;
	}

	/** Returns x. */
	public final int getX() {
		return x;
	}

	/** Returns y. */
	public final int getY() {
		return y;
	}

	/** Returns width. */
	public final int getWidth() {
		return width;
	}

	/** Returns height. */
	public final int getHeight() {
		return height;
	}
}
