/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.databinding.validate;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;

/**
 * Validator used to perform multiple validations based on sub validators.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: B255B12E2ECDEA02B0E903AAE6D64EF5
 */
public class AndValidator implements IValidator {

	/** The validators used. */
	private final IValidator[] validators;

	/** Constructor. */
	public AndValidator(IValidator... validators) {
		this.validators = validators;
	}

	/** {@inheritDoc} */
	public IStatus validate(Object value) {
		// we return the "worst" validation result, but when error or cancel
		// occurs we stop validation; we exploit the fact, that the constants
		// are given in "right" order

		IStatus result = ValidationStatus.ok();
		for (IValidator validator : validators) {
			IStatus validationResult = validator.validate(value);
			if (validationResult.getSeverity() > result.getSeverity()) {
				result = validationResult;
			}
			if (result.getSeverity() >= IStatus.ERROR) {
				break;
			}
		}

		return result;
	}

}